//
// File: PanelParametresSortie.cc
// Created by: Éric Laly <elaly@free.fr>
// Created on: Tue Oct 17 18:36:00 2006
//

#include "PanelParametresSortie.h"

PanelParametresSortie::PanelParametresSortie(wxWindow* parent, int id):wxPanel(parent, id)
{
    sizer_panel_parametres_sortie= new wxBoxSizer(wxVERTICAL);

    panel_saisie_repertoire_base=new PanelSaisieRepertoire(wxT("Répertoire de base des sorties: "),wxT(""),true, this,-1);
    sizer_panel_parametres_sortie->Add(panel_saisie_repertoire_base, 0, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 2);
    
    const wxString radio_box_type_sortie_choice[] = {
        wxT("Aucune"),
        wxT("Encadrement simple ou multiple"),
        wxT("Sortie PHPWebGallery")
    };
    radio_box_type_sortie= new wxRadioBox(this, -1, wxT("Type de sortie"), wxDefaultPosition, wxDefaultSize, 3, radio_box_type_sortie_choice, 0, wxRA_SPECIFY_COLS);
    radio_box_type_sortie->SetSelection(0);
    sizer_panel_parametres_sortie->Add(radio_box_type_sortie, 0, wxALL|wxALIGN_RIGHT|wxALIGN_CENTER_VERTICAL, 2);

    panel_encadrement.clear();
    
    SetSizer(sizer_panel_parametres_sortie);

    label_nombre_sorties = new wxStaticText(this, -1, wxT("Nombre de sorties: "));
    NombreSorties=1;
    spin_ctrl_nombre_sorties = new wxSpinCtrl(this, -1,wxT("1"), wxDefaultPosition, wxDefaultSize, wxTE_READONLY, 1, 10);
    sizer_nombre_sorties= new wxBoxSizer(wxHORIZONTAL);
    sizer_nombre_sorties->Add(label_nombre_sorties, 0, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL|wxADJUST_MINSIZE, 2);
    sizer_nombre_sorties->Add(spin_ctrl_nombre_sorties, 0, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL|wxADJUST_MINSIZE, 2);
    sizer_panel_parametres_sortie->Add(sizer_nombre_sorties, 0, wxALL|wxALIGN_RIGHT|wxALIGN_CENTER_VERTICAL, 2);
    sizer_nombre_sorties->Show(false);
    
    
    // on crée un panel scrollable qui va contenir le(s) panel(s) de paramétrage
    sw_parametre=new wxScrolledWindow(this,-1);
    sw_parametre->SetScrollRate(10,10);
    sizer_parametres= new wxBoxSizer(wxVERTICAL);
    sw_parametre->SetSizer(sizer_parametres);

    sizer_panel_parametres_sortie->Add(sw_parametre, 1, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 2);
    
	// on connecte les événements
   	Connect(radio_box_type_sortie->GetId( ), wxEVT_COMMAND_RADIOBOX_SELECTED, (wxObjectEventFunction) &PanelParametresSortie::OnRadioboxSelectedTypeSortie);
 	Connect(spin_ctrl_nombre_sorties->GetId( ), wxEVT_COMMAND_SPINCTRL_UPDATED,(wxObjectEventFunction) &PanelParametresSortie::AjouteOuEnleveSortie);

}

PanelParametresSortie::~PanelParametresSortie()
{
	// TODO: put destructor code here
}

void PanelParametresSortie::AjouteOuEnleveSortie(wxCommandEvent& event)
{
    if (NombreSorties<spin_ctrl_nombre_sorties->GetValue())
    {   
        NombreSorties=spin_ctrl_nombre_sorties->GetValue();
        wxString temp(wxT("Sortie "));temp<<NombreSorties;
        panel_encadrement.push_back(new PanelSaisieParametresImageSortie(temp,false, wxT("cadre-"), true, panel_saisie_repertoire_base->GetRepertoire(), true, sw_parametre,-1));
        sizer_parametres->Add(panel_encadrement[NombreSorties-1], 1, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 2);
    } else {
        delete panel_encadrement[NombreSorties-1];
        panel_encadrement.resize(NombreSorties-1);
        NombreSorties=spin_ctrl_nombre_sorties->GetValue();
    } 
   sizer_panel_parametres_sortie->Layout();// nécessaire 
}   

unsigned int PanelParametresSortie::GetNombreEncadrement()
{
    return panel_encadrement.size();
}    

wxString PanelParametresSortie::GetNomSortie(int index)
{
    return panel_encadrement[index]->GetNomSortie();
}    

wxString PanelParametresSortie::GetRepertoireDestination(int index)
{
    return panel_encadrement[index]->GetRepertoireDestination();
}    

wxString PanelParametresSortie::GetPrefixeFichier(int index)
{
    return panel_encadrement[index]->GetPrefixeFichier();
}

int PanelParametresSortie::GetQualiteEnregistrement(int index)
{
   return panel_encadrement[index]->GetQualiteEnregistrement();
}

int PanelParametresSortie::GetTailleRedimensionement(int index)
{
    return panel_encadrement[index]->GetTailleRedimensionement();
}

void PanelParametresSortie::OnRadioboxSelectedTypeSortie(wxCommandEvent& event)
{
    // on autorise la sortie si on a choisi un répertoire de base.
    if (!(panel_saisie_repertoire_base->GetRepertoire().IsSameAs(wxT(""))))
    {        
        switch (radio_box_type_sortie->GetSelection())
        {
            case 0:EnleveSorties();break;
            case 1:CreeSortieSimpleOuMultiple();break;
            case 2:CreeSortiePHPWebGallery();break;
        } 
    } else {
        radio_box_type_sortie->SetSelection(0);
    }    
}

void PanelParametresSortie::EnleveSorties()
{
    for (unsigned int i=0;i<panel_encadrement.size();i++)
    {
        delete panel_encadrement[i];
    }    
    panel_encadrement.clear();
    sizer_nombre_sorties->Show(false);
    sizer_panel_parametres_sortie->Layout();
}

void PanelParametresSortie::CreeSortieSimpleOuMultiple()
{
    EnleveSorties();
    spin_ctrl_nombre_sorties->SetValue(wxT("1"));
    NombreSorties=spin_ctrl_nombre_sorties->GetValue();
    sizer_nombre_sorties->Show(true);
    panel_encadrement.push_back(new PanelSaisieParametresImageSortie(wxT("Sortie 1"),false, wxT("cadre-"), true, panel_saisie_repertoire_base->GetRepertoire(), true, sw_parametre,-1));
    sizer_parametres->Add(panel_encadrement[0], 1, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 2);
    sizer_panel_parametres_sortie->Layout();// nécessaire 

}

void PanelParametresSortie::CreeSortiePHPWebGallery()
{
    EnleveSorties();
    panel_encadrement.push_back(new PanelSaisieParametresImageSortie(wxT("Image réduite"),true, wxT(""), false, panel_saisie_repertoire_base->GetRepertoire(), false, sw_parametre,-1));
    sizer_parametres->Add(panel_encadrement[0], 1, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 2);
    panel_encadrement.push_back(new PanelSaisieParametresImageSortie(wxT("Vignette"),true, wxT("TN-"), false, panel_saisie_repertoire_base->GetRepertoire()+wxT("/thumbnail"), false, sw_parametre,-1));
    sizer_parametres->Add(panel_encadrement[1], 1, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 2);
    panel_encadrement.push_back(new PanelSaisieParametresImageSortie(wxT("Image Haute Résolution"),false, wxT(""), false, panel_saisie_repertoire_base->GetRepertoire()+wxT("/pwg_high"), false, sw_parametre,-1));
    sizer_parametres->Add(panel_encadrement[2], 1, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 2);
    sizer_panel_parametres_sortie->Layout();// nécessaire 
}
